@@ -37,10 +37,7 @@ class ProteinStructureData:
             train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
         else:
             train, val = table, []
-        self.data = {
-            'train': train,
-            'val': val,
-        }
+        self.data = {'train': train, 'val': val}
 
 
 if __name__ == '__main__':
